#! /usr/bin/python

import re,sys
from os import path

from PyFoam.LogAnalysis.LogLineAnalyzer import LogLineAnalyzer
from PyFoam.LogAnalysis.BoundingLogAnalyzer import BoundingLogAnalyzer
from PyFoam.Execution.AnalyzedRunner import AnalyzedRunner
from PyFoam.Applications.ClearCase import ClearCase
from PyFoam.RunDictionary.ParsedParameterFile import ParsedParameterFile
from PyFoam.Basics.CSVCollection import CSVCollection

class AbscheideAnalyzer(LogLineAnalyzer):
    def __init__(self):
        LogLineAnalyzer.__init__(self)

        self.massLeft=0
        self.removed={}

        self.removedExpr=re.compile("Abgeschieden at (.+) with m: (.+) N: (.+) = total: (.+)")
        self.massExpr=re.compile("Current mass in system          = (.+)")
        
    def analyzeLine(self,line):
        m=self.removedExpr.match(line)
        if m!=None:
            name=m.groups()[0]
            mass=float(m.groups()[1])
            nr=float(m.groups()[2])
            total=float(m.groups()[3])

            try:
                self.removed[name]+=total
            except KeyError:
                self.removed[name] =total
            
        m=self.massExpr.match(line)
        if m!=None:
            self.massLeft=float(m.groups()[0])

    def doReport(self):
        summe=self.massLeft
        print "Mass left in system:",self.massLeft
        for k,v in self.removed.iteritems():
            print "Removed by",k,":",v
            summe+=v
        print "Total mass accounted for:",summe

    def addCSVLine(self,csv):
        csv["mass left in system"]=self.massLeft
        for k,v in self.removed.iteritems():
            csv[k]=v
        
    def addTimeListener(self,other):
        pass
        
case=sys.argv[1]
csv=CSVCollection(sys.argv[2]+".csv")

for v in [0.1, 0.5, 1, 1.5,2,3]:
    print "Velocity set to",v
    ClearCase(args=["."])
    uInit=ParsedParameterFile(path.join(case,"0","U"))
    uInit["boundaryField"]["inlet"]["value"].setUniform([v,0,0])
    uInit.writeFile()
    
    abscheid=AbscheideAnalyzer()

    run=AnalyzedRunner(abscheid,
                       argv=["rhoPisoAbscheidParcelFoam","-case",case],
                       silent=True)
    run.start()

    csv["Velocity"]=v
    abscheid.addCSVLine(csv)
    csv.write()
    
    abscheid.doReport()
