/*---------------------------------------------------------------------------*\
  =========                 |
  \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox
   \\    /   O peration     |
    \\  /    A nd           | Copyright (C) 1991-2009 OpenCFD Ltd.
     \\/     M anipulation  |
-------------------------------------------------------------------------------
License
    This file is part of OpenFOAM.

    OpenFOAM is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
    Free Software Foundation; either version 2 of the License, or (at your
    option) any later version.

    OpenFOAM is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
    for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM; if not, write to the Free Software Foundation,
    Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA

Class
    Foam::basicAbscheideCloud

Description
    Cloud class to introduce abscheide parcels

SourceFiles
    basicAbscheideCloud.C

\*---------------------------------------------------------------------------*/

#ifndef basicAbscheideCloud_H
#define basicAbscheideCloud_H

#include "KinematicCloud.H"
#include "basicAbscheideParcel.H"

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

namespace Foam
{

/*---------------------------------------------------------------------------*\
                      Class basicAbscheideCloud Declaration
\*---------------------------------------------------------------------------*/

class basicAbscheideCloud
:
    public KinematicCloud<basicAbscheideParcel>
{
    // Private member functions

        //- Disallow default bitwise copy construct
        basicAbscheideCloud(const basicAbscheideCloud&);

        //- Disallow default bitwise assignment
        void operator=(const basicAbscheideCloud&);


public:

    //- Runtime type information
    TypeName("basicAbscheideCloud");


    // Constructors

        //- Construct from components
        basicAbscheideCloud
        (
            const word& cloudName,
            const volPointInterpolation& vpi,
            const volScalarField& rho,
            const volVectorField& U,
            const volScalarField& mu,
            const dimensionedVector& g
        );


    //- Destructor
    ~basicAbscheideCloud();


    // Member functions

        //- Write fields
        virtual void writeFields() const;
};

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

} // End namespace Foam

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

#endif

// ************************************************************************* //
