/*---------------------------------------------------------------------------*\
  =========                 |
  \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox
   \\    /   O peration     |
    \\  /    A nd           | Copyright (C) 1991-2009 OpenCFD Ltd.
     \\/     M anipulation  |
-------------------------------------------------------------------------------
License
    This file is part of OpenFOAM.

    OpenFOAM is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
    Free Software Foundation; either version 2 of the License, or (at your
    option) any later version.

    OpenFOAM is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
    for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM; if not, write to the Free Software Foundation,
    Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA

\*---------------------------------------------------------------------------*/

#include "basicAbscheideParcel.H"

// * * * * * * * * * * * * * * Static Data Members * * * * * * * * * * * * * //

namespace Foam
{
    defineTypeNameAndDebug(basicAbscheideParcel, 0);
    defineParticleTypeNameAndDebug(basicAbscheideParcel, 0);
    defineParcelTypeNameAndDebug(basicAbscheideParcel, 0);
};


// * * * * * * * * * * * * * * * * Constructors  * * * * * * * * * * * * * * //


Foam::basicAbscheideParcel::basicAbscheideParcel
(
    KinematicCloud<basicAbscheideParcel>& owner,
    const label typeId,
    const vector& position,
    const label cellI,
    const scalar d0,
    const vector& U0,
    const scalar nParticle0,
    const constantProperties& constProps
)
:
    KinematicParcel<basicAbscheideParcel>
    (
        owner,
        typeId,
        position,
        cellI,
        d0,
        U0,
        nParticle0,
        constProps
    )
{}


Foam::basicAbscheideParcel::basicAbscheideParcel
(
    const Cloud<basicAbscheideParcel>& cloud,
    Istream& is,
    bool readFields
)
:
    KinematicParcel<basicAbscheideParcel>(cloud, is, readFields)
{}


Foam::basicAbscheideParcel::basicAbscheideParcel
(
    const basicAbscheideParcel& p
)
:
    KinematicParcel<basicAbscheideParcel>(p)
{}

void Foam::basicAbscheideParcel::hitPatch
(
    const polyPatch& p,
    trackData& td
)
{
    Pout << "Abgeschieden at " << p.name() << " with m: " << mass() << " N: " << nParticle() << " = total: " << mass()*nParticle() <<  endl;

    KinematicParcel<basicAbscheideParcel>::hitPatch(p,td);
}

void Foam::basicAbscheideParcel::hitPatch
(
    const polyPatch& p,
    int& td
)
{
    KinematicParcel<basicAbscheideParcel>::hitPatch(p,td);
}

// * * * * * * * * * * * * * * * *  Destructors  * * * * * * * * * * * * * * //

Foam::basicAbscheideParcel::~basicAbscheideParcel()
{}


// ************************************************************************* //
